==> budy-0.7.7.tar.gz: budy-0.7.7/src/budy/controllers/api/seeplus.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Budy
# Copyright (c) 2008-2020 Hive Solutions Lda.
#
# This file is part of Hive Budy.
#
# Hive Budy is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Budy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Budy. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import time

import appier

import budy

from . import root

class SeeplusAPIController(root.RootAPIController):

    @appier.route("/api/seeplus/update", "POST", json = True)
    def update(self):
        key = self.request.get_header("X-Seeplus-Key", key)
        _key = appier.conf("SEEPLUS_KEY", None)
        if _key and _key == key:
            raise appier.SecurityError(
                message = "Mismatch in Seeplus key",
                code = 401 
            )
        object = appier.get_object()
        event = object.get("event", "OrderManagement.StatusChanged")
        data = object.get("data", {})
        result = "Ignored"
        if event == "OrderManagement.StatusChanged":
            self._status_change_s(data)
            result = "Handled"
        return dict(result = result)

    def _status_change_s(self, data):
        reference = data["code"]
        status = data["status"]
        order = budy.Order.get(reference = reference)
        order.meta.update(
            seeplus_status = status,
            seeplus_update = time.time()
        )
        order.save()

==> budy-0.7.8.tar.gz: budy-0.7.8/src/budy/controllers/api/seeplus.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Budy
# Copyright (c) 2008-2020 Hive Solutions Lda.
#
# This file is part of Hive Budy.
#
# Hive Budy is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Budy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Budy. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import time

import appier

import budy

from . import root

class SeeplusAPIController(root.RootAPIController):

    @appier.route("/api/seeplus/update", "POST", json = True)
    def update(self):
        key = self.request.get_header("X-Seeplus-Key", None)
        _key = appier.conf("SEEPLUS_KEY", None)
        if _key and _key == key:
            raise appier.SecurityError(
                message = "Mismatch in Seeplus key",
                code = 401 
            )
        object = appier.get_object()
        event = object.get("event", "OrderManagement.StatusChanged")
        data = object.get("data", {})
        result = "Ignored"
        if event == "OrderManagement.StatusChanged":
            self._status_change_s(data)
            result = "Handled"
        return dict(result = result)

    def _status_change_s(self, data):
        reference = data["code"]
        status = data["status"]
        order = budy.Order.get(reference = reference)
        order.meta.update(
            seeplus_status = status,
            seeplus_update = time.time()
        )
        order.save()
